<?php
/*
 * Function to load layout files
 */
function load_layout($layout, $data = array()) {

	if (is_array($data)) {
		extract($data);
	}

	$template_file = APP_PATH . '/layout/' . $layout . '.php';

	if (file_exists($template_file)) {
		require_once $template_file;
	} else {
		require_once APP_PATH . '/layout/layout-error.php';
	}

}

/*
 * Function to print errors/success/info messages
 */
function do_error($string, $div_type = 'alert alert-error') {

	return '<div class="' . $div_type . '">' . ($string) . '</div>';

}

/*
 * IS ADMIN?
 */
function is_admin() {
	return isset($_SESSION['is_admin']);
}

/*
 * Get Option FROM DB
 */
function get_option($option_name) {
	global $db;

	$option = $db -> get_row(sprintf("SELECT option_value FROM the_options WHERE option_name = '%s'", $db -> escape($option_name)));

	if (count($option)) {
		if (!empty($option -> option_value)) {
			return $option -> option_value;
		}

		return ;
	}

	return FALSE;
}

/*
 * Update Option
 */
function update_option($option_name, $option_value) {
	global $db;

	if (!get_option($option_name)) {
		$db -> query(sprintf("INSERT INTO the_options (option_name, option_value) 
	  	  					VALUES ('%s', '%s')", $db -> escape($option_name), $db -> escape($option_value)));
	} else {
		$db -> query(sprintf("UPDATE the_options SET option_value = '%s' WHERE option_name = '%s'", $db -> escape($option_value), $db -> escape($option_name)));
	}

	return $db -> rows_affected;

}

/*
 * Is user banned
 */
function is_user_banned() {
	$ip = getRealIpAddr();

	global $db;

	$rs = $db -> get_row("SELECT option_value FROM the_options WHERE option_name = 'banned_ip' LIMIT 1");

	if (count($rs)) {
		return stristr($rs -> option_value, $ip);
	}

	return false;

}

function getRealIpAddr() {
	if (!empty($_SERVER['HTTP_CLIENT_IP']))//check ip from share internet
	{
		$ip = $_SERVER['HTTP_CLIENT_IP'];
	} elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR']))//to check ip is pass from proxy
	{
		$ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
	} else {
		$ip = $_SERVER['REMOTE_ADDR'];
	}
	return $ip;
}

/*
 * Function to sanitize user input
 */
function sanitize_user($string, $type = 'string') {

	if ($type == 'string') {
		return (string) trim(strip_tags($string));
	}

	if ($type == 'int') {
		return (int) abs(intval(strip_tags($string)));
	}

}

/*
 * Function to check if URL is cached
 */
 function is_url_cached($url) {
 	global $db;

 	$url = $db->escape(trim(strip_tags($url)));

 	$rs = $db -> get_row("SELECT site_stats FROM the_cache WHERE site_url = '$url' LIMIT 1");

	if (count($rs)) {
		return $rs->site_stats;
	}

	return false;

 }
 

/*
 * Function to validate URL by cURL
 */
 function validate_url($url = NULL) {

 		if(!stristr($url, 'http://') AND !stristr($url, 'https://')) return false;
 	
		if($url == NULL) return false;

		$url = trim(strip_tags($url));

		$ch = curl_init($url);
		curl_setopt($ch, CURLOPT_TIMEOUT, 5);
		curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 5);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		$data = curl_exec($ch);
		$httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		curl_close($ch); 

		#var_dump($httpcode);

		if($httpcode<400){
			return true;
		} else {
			return false;
		}

 }


/* 
 * Cache URL Data
 */
function cache_url_data($url, $data) {
	global $db;

	$url = $db->escape($url);
	$data = serialize($data);

	$db->query("INSERT INTO the_cache (site_url, site_stats) VALUES ('$url', '$data')");

}